para

# XMLRésuméLibrary: User Guide

pager | Element Reference | period

## Name

para — A paragraph of text

## Synopsis

### Content Model

    (#PCDATA|emphasis|citation|url|link)*

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `para` element contains a single paragraph of text. Its contents are not preserved verbatim; instead, it is treated much like HTML. Multiple whitespace characters (including spaces and tabs) are compressed into a single space, and linebreaks are treated as space characters instead of newlines. This allows flexibility in formatting XML source code.

Paragraphs may contain basic markup to indicate emphasis, URLs, and citations.

### Parents

`para` may be contained in these elements: `description`, `legalnotice`, `misc`, `note`, `objective`, `pub`

## Examples

    <para>
      This is a boring paragraph.
    </para>

    <para>
      I like to <emphasis>emphasize</emphasize> my words; in fact, I've written an
      article on the topic. It is published on the <emphasis><citation>Really
      Exciting WRITING!</citation></emphasis> web site at
      <url>http://www.really-exciting-writing.bob/EMPHASIS.html</url>.
    </para>

pager | Element Reference | period